# scraping-link

![scraping.link web scraping API](https://scraping.link/wp-content/uploads/2021/04/scrapinglink.png)

A Python module for Web Scraping with [Scraping.link](https://scraping.link), you will be able to scrape any website and solves typical blocking complications.

# How to Install

To install using pip run:

    pip install scraping-link

# How to use this module

This module can be used to web scraping - Extract HTML content.

Python:
import scraping-link

#### Customer Support
Simply reach out to us via [Telegram Group](https://t.me/joinchat/AwFbIh1PuwuEgCk0gVgS4g) or or write us an [email](mailto:info@scraping.link).

[Sign up for our free plan](https://app.scraping.link/register) to get a free API key loaded with 100 free credits. No credit card required!


# Licence

This software is licensed under the GNU General Public License (version 3) as published by the Free Software Foundation this licence http://www.gnu.org/licenses/ . If you would want a different licence please contact me, on twitter [@nicolasmarin](https://twitter.com/@nicolasmarin).
